GeonodeSdkBindings class
Constructors
- GeonodeSdkBindings.load()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sdkConnect(
Pointer< Void> handle) → bool -
sdkDisconnect(
Pointer< Void> handle) → bool -
sdkFree(
Pointer< Void> handle) → void -
sdkIsRunning(
Pointer< Void> handle) → bool -
sdkNew(
String apiKey, String appId, String appUserId, String appVersion, String appBuildNumber, String interopType, String interopVersion) → Pointer< Void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited